@@ -33,7 +33,7 @@ class DISCOVERCOMMON_EXPORT PackageState
 {
     public:
         PackageState(QString packageName, QString name, QString description, bool installed);
-        PackageState(QString name, QString description, bool installed);
+        PackageState(const QString &name, const QString &description, bool installed);
         PackageState& operator=(const PackageState& other);
         
         QString packageName() const;
@@ -49,4 +49,6 @@ class DISCOVERCOMMON_EXPORT PackageState
         bool m_installed;
 };
 
+DISCOVERCOMMON_EXPORT QDebug operator<<(QDebug dbg, const PackageState &state);
+
 #endif // PACKAGESTATE_H
